pub fn resolve_git_context() -> GitContextExpand description
Resolve git context (branch, worktree, commit) from the current directory.
All fields are best-effort: if git is not available or the directory is
not a git repo, fields are None.
pub fn resolve_git_context() -> GitContextResolve git context (branch, worktree, commit) from the current directory.
All fields are best-effort: if git is not available or the directory is
not a git repo, fields are None.