materialize_state

Function materialize_state 

pub fn materialize_state(events: &[AuditEvent]) -> AuditState
Replay a sequence of events to build the materialized state.

Events are processed in order. For each event, the to field (if present) becomes the current status of the entity identified by (entity, entity_id, scope).