Module changes

Module changes 

Change definitions and computed status. Change domain models and repository.

This module provides domain models for Ito changes and a repository for loading and querying change data.

Structs

Change
Full change with all artifacts loaded.
ChangeSummary
Lightweight change summary for listings.
ResolveTargetOptions
Options for resolving a change target.
Spec
A specification within a change.

Enums

ChangeLifecycleFilter
Lifecycle filter for change repository queries.
ChangeStatus
Status of a change based on task completion.
ChangeTargetResolution
Deterministic resolution result for a change target input.
ChangeWorkStatus
Work status of a change.

Traits

ChangeRepository
Port for accessing change data.

Functions

extract_module_id
Extract module ID from a change ID.
normalize_id
Normalize an ID to a fixed width with zero-padding.
parse_change_id
Parse a change identifier and return the normalized module ID and change number.
parse_module_id
Parse a module identifier and return the normalized module ID.