Change definitions and computed status. Change domain models and repository.
This module provides domain models for Ito changes and a repository for loading and querying change data.
Structs
- Change
- Full change with all artifacts loaded.
- Change
Summary - Lightweight change summary for listings.
- Resolve
Target Options - Options for resolving a change target.
- Spec
- A specification within a change.
Enums
- Change
Lifecycle Filter - Lifecycle filter for change repository queries.
- Change
Status - Status of a change based on task completion.
- Change
Target Resolution - Deterministic resolution result for a change target input.
- Change
Work Status - Work status of a change.
Traits
- Change
Repository - Port for accessing change data.
Functions
- extract_
module_ id - Extract module ID from a change ID.
- normalize_
id - Normalize an ID to a fixed width with zero-padding.
- parse_
change_ id - Parse a change identifier and return the normalized module ID and change number.
- parse_
module_ id - Parse a module identifier and return the normalized module ID.