pub fn is_safe_tracking_filename(tracking_file: &str) -> boolExpand description
Returns true when a tracking filename is safe as a single path segment.
Return true when tracking_file is safe as a single filename.
Tracking file paths are intentionally stricter than other schema-relative paths:
callers treat apply.tracks as a filename at the change directory root.